package org.eclipse.equinox.launcher;

import java.io.FilterInputStream;
import java.io.IOException;
import java.io.InputStream;

/* loaded from: org_eclipse_equinox_launcher.jar:org/eclipse/equinox/launcher/MultiInputStream.class */
public class MultiInputStream extends FilterInputStream {
    private ByteArrayBuffer buffer;

    public MultiInputStream(InputStream in) {
        super(in);
    }

    protected ByteArrayBuffer getBuffer() {
        if (this.buffer == null) {
            this.buffer = new ByteArrayBuffer();
        }
        return this.buffer;
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public synchronized int read() throws IOException {
        ByteArrayBuffer buffer = getBuffer();
        if (buffer.size() > 0) {
            byte b = buffer.getByteArray()[0];
            buffer.consumed(1);
            return b;
        }
        return super.read();
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public synchronized int read(byte[] b, int off, int len) throws IOException {
        ByteArrayBuffer buffer = getBuffer();
        if (buffer.size() > 0) {
            int count = Math.min(buffer.size(), len);
            System.arraycopy(buffer.getByteArray(), 0, b, off, count);
            buffer.consumed(count);
            return count;
        }
        return super.read(b, off, len);
    }

    public synchronized void sendMessage(String message) {
        try {
            System.out.print(message);
            getBuffer().write(message.getBytes());
        } catch (IOException unused) {
        }
    }

    @Override // java.io.FilterInputStream, java.io.InputStream
    public int available() throws IOException {
        return super.available() + getBuffer().size();
    }
}
